---
title: 결제내역 가이드
category: 관리자콘솔 (관리자콘솔 사용 가이드) > 결제내역 > 결제내역
seo:
  title: 결제내역 가이드
  description: >-
    상세내역조회, 현금영수증 관리, 정기결제 캘린더, 예약결제 내역, 본인인증 조회, 네이버 상품구매평 등 관리자콘솔 내 결제내역 관련
    정보를 확인해보세요.
  keywords:
    - 결제내역
    - 관리자콘솔
tags:
  - 공통
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 네이버페이상품평
  - 본인인증조회
  - 정기결제캘린더
  - 결제상세내역
  - 통합내역
  - 결제내역
  - 관리자콘솔
---

## **결제**

#### **1.결제내역 조회**



**기준시각**

- 결제 요청 시각 : 결제가 요청된 시각을 기준으로 조회합니다.
- 상태 승인 시각 : 결제상태가 업데이트된 최신 시각을 기준으로 조회합니다. \
  (결제취소건의 경우 취소시각으로 적용됨)

<Callout content="ex) 4월에 결제하고 5월에 취소한 거래를 > 상태 승인시각 04/01~04/30 기준으로  조회하면 결과에 포함되지 않습니다." title="조회기준에 따라 결과가 달라져요!" icon="💡 " />

**내역검색**

확인이 필요한 거래건을 특정하기 위하여 검색이 필요한 정보를 입력할 수 있습니다.

- 전체 : 입력한 단어와 여러 결제 정보 필드 중 매칭되는 거래 건을 표시합니다. 여러 필드에서 일부 혹은 전부 일치하는 경우 검색 결과에 표시됩니다. 또한, 검색의 경우 단어의 앞에서부터 일치하는 경우에만 표시되며 중간만 일치하는 경우 원하는 검색 결과를 얻지 못할 수 있습니다.
- 포트원 거래번호 : 포트원 거래번호 (imp\_uid) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 가맹점 거래번호 : 가맹점 거래번호 (merchant\_uid) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 주문명 : 주문명 (name) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 카드사 승인번호 : 카드사 승인번호 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 고객 이름 : 고객 이름 (buyer\_name) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 고객 휴대폰 번호 : 고객 휴대폰 번호 (buyer\_tel) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 고객 이메일 : 고객 이메일 (buyer\_email) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 고객 주소 : 고객 주소 (buyer\_addr) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 고객 우편번호 : 고객 우편번호(buyer\_postcode) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 결제대행사 승인번호 : 결제대행사(PG사) 승인번호 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 카드번호 : 카드번호 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다. 카드 번호의 경우 결제대행사에 따라 마스킹되는 부분이 다르므로, 앞에 6\~8자리(BIN)번호 혹은 뒷 4자리로 검색하시길 권장드립니다.
- 상점아이디 : 결제대행사 상점아이디 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 결제환경 : 결제환경(PC/MOBILE/API) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다. 검색하는 경우 대문자로 검색해야 합니다.
- 실시간 계좌 은행 : 실시간 계좌이체 거래 건에 한하여 실시간 계좌 은행 데이터 중 입력한 택스트와 일치하는 데이터가 표시됩니다. (ex. 실시간 계좌이체 거래 건의 계좌은행이 토스뱅크인 경우 )
- 가상계좌 은행 : 가상계좌 거래 건에 한하여 가상계좌 은행 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 계좌번호 : 가상계좌 거래 건에 한하여 계좌번호 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 입금자명 : 가상계좌 거래 건에 한하여 입금자명 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 현금영수증 발급번호 : 실시간 계좌이체 또는 가상계좌 거래 시 현금영수증을 발급한 거래 건에 한하여 현금영수증 발급번호(국세청 승인번호) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 취소 사유 : 결제 취소 건에 한하여 취소 사유 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다. 포트원 어드민콘솔에서 취소한 경우 취소 사유는 관리자페이지취소로 일괄 입력됩니다.
- 카드사명 : 카드사명 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 할부개월수 : 카드 결제 시 할부가 적용된 거래 건에 한하여 할부개월수 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.

**필터**

- 결제상태/결제수단/결제대행사/결제유형/결제모드로 구분된 필터로 검색조건을 제어할 수 있습니다.

<Callout content="테스트용 상점아이디로 결제된 건은 테스트결제를 반드시 체크해주셔야 조회가 가능합니다." icon="💡 " />

**결제 상태**

- 전체 : 모든 결제상태의 거래를 조회합니다.
- 결제완료:조회하시는 시점에 결제상태가 완료(status: paid)된 건의 거래를 조회합니다. (결제취소건 미포함)
- 결제예정 : 조회하시는 시점에 결제상태가 예정(status: ready)된 건의 거래를 조회합니다.
  - 결제창을 띄운 직후 결제의 상태는 결제예정(ready)로 저장됩니다.
  - 결제가 최종적으로 완료되면서 승인되면 결제완료(paid)로 상태가 변경되어 저장되나, 결제도중 모종의 이유로 인하여 고객이 결제창을 이탈한 경우에는 처음 저장된 상태(ready) 그대로 남게 됩니다.
- 결제실패 : 조회하시는 시점에 결제상태가 실패(status: failed)된 건의 거래를 조회합니다.
- 결제취소 : 조회하시는 시점에 결제상태가 취소(status: cancelled)된 건의 거래를 조회합니다.
- 승인대기 : 조회하시는 시점에 결제상태가 승인대기(status: pending)된 건의 거래를 조회합니다.\
  승인대기는 페이팔(SPB/RT)을 이용하실 경우에만 존재하는 결제상태로, 결제 및 환불 요청 완료 후 승인되기까지 결제상태를 의미합니다.

**집계**

- 순 거래액 : (조회된 결제내역 기준) 총 결제완료액 - 결제취소액
- EXCEL 다운로드 : 조회된 내역을 excel 데이터로 다운로드 받을 수 있습니다.

**조회결과**

- 조회결과 항목 확인하기
  - 결제상태 : 거래별로 해당되는 결제상태를 표기합니다. (결제상태는 ④번 항목을 자세히 참조해주세요.)
  - UID/MID
    - UID : 포트원의 주문번호. imp\_숫자12자리 형태입니다. \
      (정기결제는 imps\_숫자12자리) 결제창이 호출되자마자 자동으로 생성/저장되는 번호.
  - 상품명 : 결제요청시 지정하신 상품명(name)
  - 고객정보 : 결제요청시 지정하신 고객명(buyer\_name)
  - 결제수단 : 결제요청하신 결제수단
  - 결제대행사 : 결제요청하신 결제대행사(PG사)
  - 결제금액 : 총 결제금액
  - 구분 : 정기(정기결제 실 연동), 테스트 | 정기(정기결제 테스트), 테스트 | 일반(일반결제 테스트) 으로 구분됩니다.
  - 결제요청시각 / 상태승인시각 : 조회하신 기준시각 기준으로 적용된 시각. (검은바탕에는 일자가 표기됩니다)
  - 취소 : 거래 취소를 위한 버튼
  - ≡ : 거래 상세내역 조회를 위한 버튼



#### **2. 빌링결제 내역조회**

포트원을 통해 발생한 빌링키 결제 내역을 상태별로 조회하고 결제 예약일 변경, 예약 해지, 결제 재시도, 결제 재예약 기능을 이용하여 빌링 결제 건을 관리할 수 있으며, 결제 실패 건에 대한 일괄 재시도를 자동화해주는 리커버리 기능에 대해 안내합니다.

<Callout content="빌링결제 상세 내역 조회 및 캘린더의 경우 상점별로 데이터가 표시됩니다. 하위상점을 생성하여 사용하시는 경우 오른쪽 상단의 상점을 선택하여 해당 상점의 데이터를 확인할 수 있습니다." title="참고사항" icon="💡 " />

##### **상세 내역 조회**

발급한 빌링키를 이용하여 [빌링키 결제 API](https://developers.portone.io/api/rest-v2/payment#post%20%2Fpayments%2F%7BpaymentId%7D%2Fbilling-key) 혹은 [결제 예약 API](https://developers.portone.io/api/rest-v2/paymentSchedule#post%20%2Fpayments%2F%7BpaymentId%7D%2Fschedule)로 시도된 거래 건을 상태별로 조회할 수 있습니다.



##### **조회 기준**

- 상태별 최종 업데이트 일시(default) : 예약, 성공, 실패, 해지 상태 건에 대해 최종 업데이트 일시를 기준으로 조회합니다. (결제 예약건의 경우 예약 예정 시각을 기준으로 조회됩니다.)
- 빌링결제 등록 일시 : 예약결제의 경우 예약건이 등록된 일시를 기준으로, 빌링키 일회성 결제 건의 경우 결제를 시도한 일시를 기준으로 조회합니다.
- 오늘 : 오늘 00시 00분 00초부터 23시 59분 59초로 설정됩니다.
- 최근7일 : 오늘을 기준으로 D-7일로 설정됩니다.
- 이번 달 : 이번달 1일부터 말일까지로 설정됩니다.
- 올해 : 올해 1월 1일부터 12월 31일까지로 설정됩니다.

##### **필터**

필터에 따라 빌링 결제 내역을 필터링하여 조회할 수 있습니다. 필터는 결제대행사에 따라 다중 선택할 수 있습니다.

##### **결제대행사**

- 전체 : 모든 결제대행사의 거래를 조회합니다.
- 결제대행사 필터는 하나의 결제대행사에 모든 pg\_provider가 포함됩니다.
  - KG 이니시스 : inicis, html5\_inicis, inicis\_v2
  - 나이스페이먼츠 : nice, nice\_v2
  - 페이팔 : paypal, paypal\_v2
  - 스마트로 : smartro, smartro\_v2
  - 토스페이 : tosspay, tosspay\_v2
  - 토스페이먼츠 : uplus, tosspayments

##### **내역검색**

빌링 결제 정보를 검색하여 거래건을 특정할 수 있습니다.

- 빌링결제 아이디 : 빌링결제 아이디(schedule\_id) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 고객사 거래번호 : 고객사 거래번호(paymentId) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 포트원 빌링키 : 포트원 빌링키(billingKey) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 고객 식별 정보 : 고객식별정보 (customer.id) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 고객 이름: 고객 이름 (customer.name) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.
- 상품 이름 : 상품 이름 (orderName) 데이터 중 입력한 텍스트와 일치하는 데이터가 표시됩니다.

##### **리커버리**

<Callout content="전날 실패한 모든 빌링결제를 매일 설정한 시간에 자동으로 재시도합니다. 
예를 들어 리커버리 시간을 16시로 설정한 경우 매일 16시에 전날 00시~23시59분까지 발생한 결제 실패 건에 대해 일괄 재시도를 시도합니다. 이 때, 결제 실패된 경우 다음 날 리커버리 항목에 포함되며, 결제 성공 상태가 될 때까지 계속해서 시도합니다.

※ 리커버리 시간 설정은 01시부터 23시까지 가능합니다.
" title="참고사항" icon="💡 " />

빌링키 결제 API 및 결제 예약 API를 이용한 결제 건 중 결제 실패 상태인 거래 건에 한하여 리커버리 기능을 사용할 수 있습니다.



##### **상태별 상세조회**

- 전체 : 모든 빌링 결제 상태의 거래를 조회합니다.
- 예약 : 예약 (status : Scheduled) 상태인 거래 건만 표시됩니다.
- 성공 : 결제 대기 (status : Pending) 및 결제 성공 (status : Succeeded) 상태인 거래 건만 표시됩니다.
- 실패 : 실패 (status : Failed) 상태인 거래 건만 표시됩니다.
- 해지 : 해지 (status : Revoked) 상태인 거래 건만 표시됩니다.

<Callout title="빌링결제 상태별 상세조회 보러가기 ↗" />

#### **2-1. 빌링결제 캘린더**

<Callout content="빌링결제 캘린더에서는 빌링결제 건에 대한 월간/일간 데이터를 확인할 수 있습니다.
" title="참고사항" icon="💡 " />

##### 기준

- 페이지 최초 진입 시 해당 월을 기준으로 데이터가 표시되며, 월을 조정하여 해당 월의 빌링결제 데이터를 확인할 수 있습니다.
- 기본적으로 거래 금액을 기준으로 표시되며, 토글을 클릭하여 건수를 기준으로 데이터 확인이 가능합니다.
- 기본적으로 KRW를 기준으로 표시되며, 해외 통화 빌링 결제 거래건이 있는 경우 해당 통화를 선택할 수 있으며 각 통화별 빌링결제 데이터를 확인할 수 있습니다.
- 해당 월의 결제예약 / 결제성공 / 결제실패 / 예약해지 상태별로 거래 금액 혹은 건수 데이터를 확인할 수 있습니다.



#### **3. 현금영수증 관리**

<Callout content="- 현재 현금영수증 관리 메뉴는 (구)관리자콘솔에서만 지원가능하며, 추후 신규 관리자콘솔에서도 기능이 추가될 예정입니다. 
- API로 현금영수증 발행한 건에 한하여 조회가능합니다. (지원가능한 결제대행사 확인필요)" title="참고사항" icon="💡 " />



**발급내역 구분**

- 포트원 거래분 : 포트원을 통해 결제된 거래에 대한 현금영수증 발행분을 의미합니다.
  - 발행 API : [POST `/receipts/{imp_uid}`](https://developers.portone.io/api/rest-v1/receipt#get%20%2Freceipts%2F%7Bimp_uid%7D)
- 고객사 자체 거래분 : 포트원을 통해 결제되지 않은 거래에 대한 현금영수증 발행분을 의미합니다.
  - 발행 API : [POST `/receipts/external/{merchant_uid}`](https://developers.portone.io/api/rest-v1/receipt#post%20%2Freceipts%2Fexternal%2F%7Bmerchant_uid%7D)\`(포트원을 통해 결제되지 않은 건이어도 위 API로 현금영수증 발행이 가능합니다)

**조회기준**

- \#포트원 거래고유번호(imp\_uid) : 거래건별 포트원의 고유번호로 검색가능합니다.
- \#고객사 주문번호(merchant\_uid) : 거래건별 고객사에서 지정하신 고유번호로 검색가능합니다.
- \#발급상태 : 전체, 발급, 취소 로 검색가능합니다.
- \#검색기간(발급/취소일자) : 달력으로 검색기간 조정이 가능합니다.

**조회결과**

- 발행PG사 : 발행된 PG사명
- 포트원 거래고유번호(imp\_uid) : 거래건별 포트원의 고유번호
- 고객사 주문번호(merchant\_uid) : 거래건별로 고객사에서 지정하신 고유번호
- 결제일자 : 거래가 승인된 결제일
- 현금영수증 발급번호 : 현금영수증 발급후 응답되는 발급번호
- 발급유형(type) : 소득공제용 혹은 지출증빙용
- 발급상태 : 발급여부 노출
- 발급일자 : 현금영수증 발급일자
- 발급취소일자 : (발급 취소된 경우) 취소일자
- 발급금액총계(부가세) : 총금액(부가세) 표기

#### **4. 본인인증 조회**

**본인인증 내역**

<Callout content="- 본인인증 조회 메뉴는 (구)관리자콘솔에서만 지원가능합니다. 
- 추후 신규 관리자콘솔에서도 기능이 추가될 예정입니다." icon="💡 " title="참고사항" />



**조회기준**

- 조회조건 : 조건없음, 포트원 거래고유번호, 고객사 주문번호
- 조회기간(본인인증 시도시각 기준) : 본인인증 시도시각 기준으로 조회기간/시각 설정가능
- 조회건수 : 100건, 500건, 1000건

**조회결과**

<Callout content="" title="인증이 성공하지 않은 건은 인증자의 상세 데이터가 없는 것이 정상입니다!" icon="⚠️" />

- imp\_uid : 본인인증 건별로 부여되는 고유 주문번호 (포트원에서 자동생성됩니다)
- merchant\_uid : 본인인증 건별로 지정하시는 고객사의 고유 주문번호 (인증창 호출시 고객사에서 지정합니다)
- PG사/PG상점아이디 : 시도하신 PG사와 상점아이디
- PG사 거래번호 : 인증성공시 PG사에서 응답된 거래번호
- 이름/성별/생년월일/통신사,전화번호/인증여부/시도시각,인증시각
  - 인증성공시 인증자의 정보(다날 본인인증의 경우 별도 요청하지 않으신 경우 통신사,휴대폰번호 정보 확인이 불가합니다.

<Callout title="휴대폰 본인인증 추가 정보 취득방법 보러가기 ↗" />

#### **5. 네이버 상품구매평**



- 네이버페이 상품구매평 : 구매자가 네이버페이에 남긴 구매평 확인가능
- 네이버페이 쇼핑문의내역 : 구매자가 네이버페이에 남긴 쇼핑문의내역 확인가능
